@@ -25,4 +25,6 @@ pub mod sparse_table;
 /// Binary Tree
 pub mod binary_tree;
 /// DSU (disjoint-set-union)
-pub mod dsu;
\ No newline at end of file
+pub mod dsu;
+/// Sheduling algorithms
+pub mod sheduling;
\ No newline at end of file
